@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Iterator::Rule;
 # ABSTRACT: Iterative, recursive file finder
-our $VERSION = '1.008'; # VERSION
+our $VERSION = '1.009';
 
 # Register warnings category
 use warnings::register;
@@ -432,6 +432,7 @@ sub _regexify {
     my ( $re, $add ) = @_;
     $add ||= '';
     my $new = ref($re) eq 'Regexp' ? $re : Text::Glob::glob_to_regex($re);
+    return $new unless $add;
     my ( $pattern, $flags ) = regexp_pattern($new);
     my $new_flags = $add ? _reflag( $flags, $add ) : "";
     return qr/$new_flags$pattern/;
@@ -717,7 +718,7 @@ Path::Iterator::Rule - Iterative, recursive file finder
 
 =head1 VERSION
 
-version 1.008
+version 1.009
 
 =head1 SYNOPSIS
 
@@ -1535,6 +1536,8 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords David Steinbrunner Gian Piero Carrubba Graham Knop Ricardo Signes Toby Inkster
+
 =over 4
 
 =item *
